@@ -18,15 +18,17 @@
 
 (define (asy-launcher)
   (if (url-exists? "$TEXMACS_HOME_PATH/plugins/tmpy")
-      (string-append "python3.7 \""
+      (string-append (python-command) " \""
                      (getenv "TEXMACS_HOME_PATH")
                      "/plugins/tmpy/session/tm_asy.py\"")
-      (string-append "python3.7 \""
+      (string-append (python-command) " \""
                      (getenv "TEXMACS_PATH")
                      "/plugins/tmpy/session/tm_asy.py\"")))
 
 (plugin-configure asymptote
+  (:winpath "Asymptote" ".")
   (:require (url-exists-in-path? "asy"))
+  (:require (python-command))
   (:launch ,(asy-launcher))
   (:serializer ,asy-serialize)
   (:session "Asymptote")
