@@ -22,7 +22,7 @@
   (map (lambda (x)
          (string-replace (string-replace x ", lisp" "") "version " ""))
    (filter (lambda (x) (string-starts? x "version "))
-     (string-split (var-eval-system "maxima --list-avail") #\nl))))
+     (string-split (var-eval-system "maxima --list-avail") #\newline))))
 
 (define (maxima-launchers) ;; returns list of launchers for each version
   (if (os-mingw?)
@@ -49,10 +49,10 @@
               (cons launch-default launch-rest))
             '()))))
 
-(plugin-add-macos-path "Maxima*" "Contents/Resources/maxima/bin" #f)
-(plugin-add-macos-path "Maxima*" "Contents/Resources/opt/bin" #f)
-(plugin-add-windows-path "Maxima*" "bin" #f)
-(plugin-add-windows-path "maxima*" "bin" #f)
+(plugin-add-macos-path "Maxima*" "Contents/Resources/maxima/bin" #t)
+(plugin-add-macos-path "Maxima*" "Contents/Resources/opt/bin" #t)
+(plugin-add-windows-path "Maxima*" "bin" #t)
+(plugin-add-windows-path "maxima*" "bin" #t)
 
 (plugin-configure maxima
   (:require (url-exists-in-path? "maxima"))
