@@ -11,15 +11,11 @@
 ## in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 
 
-function tmdisp(M)
-  if (length (getenv ("TEXMACS_PATH")) > 0)
-    tmp= obj2scm (M);
-    if strcmp (tmp,"")
-      disp (M);
-    else
-      flush_scheme (tmp)
-    endif
+function tmdisp (M)
+  scheme_to_flush= obj2scm (M);
+  if length (scheme_to_flush) == 0
+    flush_verbatim (M);
   else
-    disp (M);
+    flush_scheme (scheme_to_flush);
   endif
 endfunction
