@@ -1440,11 +1440,19 @@
       `(document ,@l)
       `(!item ,(cadar l) (document ,(caddar l) ,@(cdr l)))))
 
+(define (item? x) (tm-in? x '(item item*)))
+
 (define (transform-items x)
-  (cond ((and (tm-is? x 'concat)
-              (nnull? (cdr x))
-              (tm-in? (cadr x) '(item item*)))
+  (cond ((and (tm-is? x 'concat) (nnull? (cdr x))
+              (item? (cadr x)))
          `(!item ,(cadr x) (concat ,@(cddr x))))
+        ((and (tm-is? x 'concat) (nnull? (cdr x)) (nnull? (cddr x))
+              (tm-is? (cadr x) 'assign) (item? (caddr x)))
+         `(!item ,(caddr x) (concat ,@(cdddr x))))
+        ((item? x)
+         `(!item ,x (hspace "1pt")))
+        ((tm-is? x 'with)
+         `(,@(cDr x) ,(transform-items (cAr x))))
         ((tm-is? x 'document)
          (let* ((r  (map transform-items (cdr x)))
                 (p? (lambda (i) (tm-is? i '!item)))
