@@ -100,6 +100,7 @@
 					      (!math (longhookrightarrow))))))
   (Backepsilon (!group (mbox (rotatebox (!option "origin=c") "180"
 					"E"))))
+  (Backsigma (!group (mbox (reflectbox (!math "\\Sigma")))))
   (Mho (!group (mbox (rotatebox (!option "origin=c") "180"
 				(!math "\\Omega")))))
   (btimes (!group (mbox (rotatebox (!option "origin=c") "90"
@@ -132,7 +133,9 @@
   (mathD "\\mathrm{D}")
   (mathe "\\mathrm{e}")
   (matheuler "\\gamma")
+  (mathGamma "\\Gamma")
   (mathlambda "\\lambda")
+  (mathLaplace "\\Delta")
   (mathi "\\mathrm{i}")
   (mathpi "\\pi")
   (Alpha "\\mathrm{A}")
@@ -155,12 +158,34 @@
   (divides "\\mathrel{|}")
   (ndivides "\\mathrel{\\nmid}")
   (asterisk "\\mathord{*}")
-  (npreccurlyeq (!annotate "\\mathrel{\\not\\preccurlyeq}" (preccurlyeq)))
   (dottimes "\\mathbin{\\dot{\\times}}")
-  (nequiv "\\mathrel{\\not\\equiv}")
   (precdot "\\mathrel{\\prec\\!\\!\\cdot")
-  
+
+  ;; negations
+  (nin "\\not\\in")
+  (nni "\\not\\ni")
+  (notni "\\not\\ni")
+  (nequiv (!annotate "\\mathrel{\\not\\equiv}" (equiv)))
+  (nleadsto (!annotate "\\not\\leadsto" (leadsto)))
+  (napproxeq (!annotate "\\mathrel{\\not\\approxeq}" (approxeq)))
+  (nprecapprox (!annotate "\\mathrel{\\not\\precapprox}" (precapprox)))
+  (npreccurlyeq (!annotate "\\mathrel{\\not\\preccurlyeq}" (preccurlyeq)))
+  (npreceqq (!annotate "\\mathrel{\\not\\preceqq}" (preceqq)))
+  (nprecsim (!annotate "\\mathrel{\\not\\precsim}" (precsim)))
+  (nsimeq (!annotate "\\mathrel{\\not\\simeq}" (simeq)))
+  (nsqsubset (!annotate "\\mathrel{\\not\\sqsubset}" (sqsubset)))
+  (nsqsubseteq (!annotate "\\mathrel{\\not\\sqsubseteq}" (sqsubseteq)))
+  (nsqsubseteqq (!annotate "\\mathrel{\\not\\sqsubseteqq}" (sqsubseteqq)))
+  (nsqsupset (!annotate "\\mathrel{\\not\\sqsupset}" (sqsupset)))
+  (nsqsupseteq (!annotate "\\mathrel{\\not\\sqsupseteq}" (sqsupseteq)))
+  (nsqsupseteqq (!annotate "\\mathrel{\\not\\sqsupseteqq}" (sqsupseteqq)))
+  (nsuccapprox (!annotate "\\mathrel{\\not\\succapprox}" (succapprox)))
+  (nsucccurlyeq (!annotate "\\mathrel{\\not\\succcurlyeq}" (succcurlyeq)))
+  (nsucceqq (!annotate "\\mathrel{\\not\\succeqq}" (succeqq)))
+  (nsuccsim (!annotate "\\mathrel{\\not\\succsim}" (succsim)))
+
   ;; other extra symbols
+  (oempty "\\circ")
   (exterior "\\wedge")
   (Exists "\\exists")
   (bigintwl "\\int")
@@ -178,10 +203,6 @@
   (nocomma "")
   (noplus "")
   (nosymbol "")
-  (nin "\\not\\in")
-  (nni "\\not\\ni")
-  (notni "\\not\\ni")
-  (nleadsto (!annotate "\\not\\leadsto" (leadsto)))
   (dotminus "\\mathaccent95{-}")
   (dotpm "\\mathaccent95{\\pm}")
   (dotmp "\\mathaccent95{\\mp}")
@@ -210,23 +231,86 @@
   (timesassign "\times\\!\\!=")
   (overassign "/\\!\\!=")
   (backassign "=:")
+  (pplus (mathbin "+\\!\\!\\!\\!+"))
   (lflux "\\ll")
   (gflux "\\gg")
   (colons "\\,:\\,")
   (transtype "\\,:\\!!>")
+  (tmxspace (hspace "1em"))
   (lebar (mathrel (Yleft)))
   (gebar (mathrel (Yright)))
   (leangle (mathrel (angle)))
   (geangle (mathrel (!group (mbox (reflectbox (!math (angle)))))))
-  (leqangle (mathrel (substack (!append (angle) "\\\\" "-"))))
-  (geqangle (mathrel (!group (mbox (reflectbox (!math (substack (!append (angle) "\\\\" "-"))))))))
+  (anglege (mathrel (!group (mbox (rotatebox (!option "origin=c") "180"
+                                             (!math (angle)))))))
+  (anglele (mathrel (!group (mbox (rotatebox (!option "origin=c") "180"
+                                             (!math (!recurse (geangle))))))))
+  ;;(leqangle (mathrel (substack (!append (angle) "\\\\" (smash "-")))))
+  (leqangle (mathrel (!append (angle) " \\llap "
+                              (!group (raisebox "-1ex" (!math "-"))))))
+  (geqangle (mathrel (!group (mbox (reflectbox (!math (!recurse (leqangle))))))))
+  (legeangle (mathrel (substack (!append (leangle) "\\\\" (!recurse (anglege))))))
+  (geleangle (mathrel (substack (!append (geangle) "\\\\" (!recurse (anglele))))))
   (udots "{\\mathinner{\\mskip1mu\\raise1pt\\vbox{\\kern7pt\\hbox{.}}\\mskip2mu\\raise4pt\\hbox{.}\\mskip2mu\\raise7pt\\hbox{.}\\mskip1mu}}")
   (subsetsim (underset (sim) (subset)))
   (supsetsim (underset (sim) (supset)))
   (rightmap (!group (!append (shortmid) "\\!\\!\\!-")))
   (leftmap (!group (!append "-\\!\\!\\!" (shortmid))))
   (leftrightmap (!group (!append (shortmid) "\\!\\!\\!-\\!\\!\\!"
-                                 (shortmid)))))
+                                 (shortmid))))
+  (LRleftrightarrow (!group (!append (Lleftarrow) "\\!\\!\\!" (Rrightarrow))))
+  (Llongleftarrow (!group (!append (Lleftarrow) "\\!" (equiv))))
+  (Llongrightarrow (!group (!append (equiv) "\\!" (Rrightarrow))))
+  (Llongleftrightarrow (!group (!append (Lleftarrow) "\\!" (equiv)
+                                        "\\!" (Rrightarrow))))
+  (threeleftarrows
+   (mathrel (substack (!append (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow)))))
+  (fourleftarrows
+   (mathrel (substack (!append (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow)))))
+  (threerightarrows
+   (mathrel (substack (!append (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow)))))
+  (fourrightarrows
+   (mathrel (substack (!append (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow)))))
+  (longleftrightarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longrightarrow)))))
+  (longleftleftarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longthreeleftarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longfourleftarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longrightleftarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longrightrightarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow)))))
+  (longthreerightarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow)))))
+  (longfourrightarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Extra TeXmacs macros
@@ -245,27 +329,36 @@
     (!append (!translate "This document has been produced using the GNU") " "
              (!group (!recurse (TeXmacs))) " " (!translate "text editor") " ("
              (!translate "see") " "
-             (url "http://www.texmacs.org") ")"))
+             (url "https://www.texmacs.org") ")"))
+  (citewebsite
+    (!append (!translate "This document has been written using") " GNU "
+             (!group (!recurse (TeXmacs))) "; " (!translate "see") " "
+             (url "https://www.texmacs.org") "."))
+  (tmmade (!recurse (tikzframe (Backsigma))))
   (scheme "{\\sc Scheme}")
   (tmsep  ", ")
   (tmSep  "; ")
   (pari "{\\sc Pari}")
-  (qed (!math (Box)))
+  (textdots "...")
+  (filldots "{\\dotfill\\hfill\\hbox{}}")
+  (infixand (text " and "))
+  (infixor (text " or "))
+  (infixiff (text " iff "))
 
   ;; Unary macros
   (tmrsub (ensuremath (!append "_{" (textrm 1) "}")))
   (tmrsup (textsuperscript 1))
-  (tmverbatim (!group (ttfamily) (!group 1)))
-  (tmtextrm (!group (rmfamily) (!group 1)))
-  (tmtextsf (!group (sffamily) (!group 1)))
-  (tmtexttt (!group (ttfamily) (!group 1)))
-  (tmtextmd (!group (mdseries) (!group 1)))
-  (tmtextbf (!group (bfseries) (!group 1)))
-  (tmtextup (!group (upshape) (!group 1)))
-  (tmtextsl (!group (slshape) (!group 1)))
-  (tmtextit (!group (itshape) (!group 1)))
-  (tmtextsc (!group (scshape) (!group 1)))
-  (tmmathbf (ensuremath (boldsymbol 1)))
+  (tmverbatim (text (!group (ttfamily) (!group 1))))
+  (tmtextrm (text (!group (rmfamily) (!group 1))))
+  (tmtextsf (text (!group (sffamily) (!group 1))))
+  (tmtexttt (text (!group (ttfamily) (!group 1))))
+  (tmtextmd (text (!group (mdseries) (!group 1))))
+  (tmtextbf (text (!group (bfseries) (!group 1))))
+  (tmtextup (text (!group (upshape) (!group 1))))
+  (tmtextsl (text (!group (slshape) (!group 1))))
+  (tmtextit (text (!group (itshape) (!group 1))))
+  (tmtextsc (text (!group (scshape) (!group 1))))
+  (tmmathbf (ensuremath (!recurse (boldsymbol 1))))
   (tmmathmd (ensuremath 1))
   (tmop (ensuremath (operatorname 1)))
   (tmstrong (textbf 1))
@@ -284,6 +377,7 @@
   (tmdef 1)
   (dueto (textup (textbf (!append "(" 1 ") "))))
   (op 1)
+  (todo (!group (!append (color "red!75!black") "[To do: " 1 "]")))
   (tmoutput 1)
   (tmerrput (!append (color "red!50!black") 1))
   (tmtiming (!append (hfill) (footnotesize) (color "black!50") 1 (par)))
@@ -301,10 +395,31 @@
   (tmieeeemail (!append (textit (!translate "Email:")) " " 1))
   (tmnote (thanks (!append (textit (!translate "Note:")) " " 1)))
   (tmmisc (thanks (!append (textit (!translate "Misc:")) " " 1)))
+  (citetexmacs
+    (!append (!translate "This document has been written using") " GNU "
+             (!group (!recurse (TeXmacs))) " " (cite 1) "."))
   (key (!append
          (fcolorbox "black" "gray!25!white"
                     (raisebox "0pt" (!option "5pt") (!option "0pt") (texttt 1)))
          (hspace "0.5pt")))
+  (uhat (underaccent (hat) 1))
+  (uwidehat (underaccent (widehat (hphantom 1)) 1))
+  (utilde (underaccent (tilde) 1))
+  (uwidetilde (underaccent (widetilde (hphantom 1)) 1))
+  (uvec (underaccent (vec) 1))
+  (ubreve (underaccent (breve) 1))
+  (uinvbreve (underaccent (invbreve) 1))
+  (ucheck (underaccent (check) 1))
+  (uring (underaccent (ring) 1))
+  (uacute (underaccent (acute) 1))
+  (ugrave (underaccent (grave) 1))
+  (underdot (underaccent (dot) 1))
+  (uddot (underaccent (ddot) 1))
+  (udddot (underaccent (dddot (hphantom 1)) 1))
+  (uddddot (underaccent (ddddot (hphantom 1)) 1))
+  (widespacing 1)
+  (gb  (!append (texttt "[\\!\\![") 1 (texttt "]\\!\\!]")))
+  (gbt (!append (texttt "[\\!\\![\\!\\![") 1 (texttt "]\\!\\!]\\!\\!]")))
 
   ;; With options
   (tmcodeinline ((!option "") (!group (ttfamily) (!group 2))))
@@ -384,6 +499,7 @@
   (ontop (genfrac "" "" "0pt" "" 1 2))
   (subindex (index (!append 1 "!" 2)))
   (renderfootnote (footnotetext (!append (tmrsup 1) " " 2)))
+  (renderfootnotestar (footnotetext (!append (tmrsup 1) " " 3)))
   (tmlinenumber (!append (custombinding 1)
                          (tmlinenote (footnotesize 1) 2 "0cm")))
 
@@ -473,8 +589,18 @@
    (!append (begingroup) "\\setlength{\\parskip}{" 1 "}"
             ---
             (endgroup)))
+  ("tmcompact"
+   ((!begin "tmparsep" "0em") ---))
+  ("tmcompressed"
+   ((!begin "tmparsep" "0.25em") ---))
+  ("tmamplified"
+   ((!begin "tmparsep" "0.75em") ---))
+  ("tmjumpin"
+   ((!begin "tmparmod" "1.5em" "0pt" "-1.5em") ---))
   ("tmindent"
    ((!begin "tmparmod" "1.5em" "0pt" "0pt") ---))
+  ("tmlisting"
+   ((!begin "linenumbers") (!append (resetlinenumber) ---)))
   ("elsequation" ((!begin "eqnarray") (!append --- "&&")))
   ("elsequation*" ((!begin "eqnarray*") (!append --- "&&")))
   ("theglossary"
@@ -516,6 +642,7 @@
 (latex-texmacs-description "descriptionaligned")
 (latex-texmacs-description "descriptiondash")
 (latex-texmacs-description "descriptionlong")
+(latex-texmacs-description "descriptionparagraphs")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Extra preamble definitions which are needed to export certain macros
@@ -525,9 +652,18 @@
   (newmdenv
    (!append (mdfsetup (!append "linecolor=black,linewidth=0.5pt,"
 			       "skipabove=0.5em,skipbelow=0.5em,"
-			       "hidealllines=true,\ninnerleftmargin=0pt,"
+			       "hidealllines=true,innerleftmargin=0pt,"
 			       "innerrightmargin=0pt,innertopmargin=0pt,"
 			       "innerbottommargin=0pt" )) "\n"))
+  (tikzframe
+   (!append
+    (!ignore (tikz))
+    "\\newcommand{\\tikzframe}[1]{%\n"
+    "  \\tikz[baseline=(X.base)]\n"
+    "  \\node[draw=black,semithick,rectangle,inner sep=2pt,rounded corners=2pt]\n"
+    "  (X) {#1};}\n"))
+  (nonconverted
+   (!append "\\newcommand{\\nonconverted}[1]{\\mbox{}}\n"))
   (tmkeywords
    (!append (newcommand (tmkeywords)
 			(!append (textbf (!translate "Keywords:")) " "))
@@ -577,9 +713,15 @@
 		       (!translate "Misc:") " #2}}\n"))
   (thankssubtitle (!append "\\newcommand{\\thankssubtitle}[2][]{\\thanks[#1]{"
                            (!translate "Subtitle:") " #2}}\n"))
+  (qed (!append (providecommand "\\qed" (ensuremath (Box))) "\n"))
   (mho
    (!append
     "\\renewcommand{\\mho}{\\mbox{\\rotatebox[origin=c]{180}{$\\omega$}}}"))
+  (invbreve
+   (!append
+    "\\usepackage[T3,T1]{fontenc}\n"
+    "\\DeclareSymbolFont{tipa}{T3}{cmr}{m}{n}\n"
+    "\\DeclareMathAccent{\\invbreve}{\\mathalpha}{tipa}{16}\n"))
   (custombinding
    (!append
     "\\newcounter{tmcounter}\n"
@@ -608,7 +750,9 @@
     "      \\tmfloatcontents\n"
     "      \\captionof{#3}{#5}\n"
     "    \\end{center}\n"
-    "  \\end{minipage}}\n")))
+    "  \\end{minipage}}\n"))
+  (addtocountergroup (!append "\\newcommand{\\addtocountergroup}[2]{}\n"))
+  (groupcommoncounter (!append "\\newcommand{\\groupcommoncounter}[1]{}\n")))
 
 ;;(define-macro (latex-texmacs-long prim x l m r)
 ;;  `(smart-table latex-texmacs-preamble
@@ -646,10 +790,21 @@
 ;; Plain style theorems
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define-macro (latex-texmacs-thmenv prim name before after)
-  `(smart-table latex-texmacs-env-preamble
-     (,prim (!append ,@before (newtheorem ,prim (!translate ,name))
-		     ,@after "\n"))))
+(tm-define-macro (latex-texmacs-thmenv prim name before after . opt-mode)
+  (let* ((head (if (null? opt-mode) (list) (list `(:mode ,(car opt-mode)))))
+         (prim* (string-append prim "*"))
+         (nonum (string-append "nn" prim))
+         (thenonum (string-append "\\the" nonum)))
+    `(smart-table latex-texmacs-env-preamble
+       ,@head
+       (,prim  (!append ,@before
+                        (newtheorem ,prim (!translate ,name))
+                        ,@after "\n"))
+       (,prim* (!append (newcounter ,nonum) "\n"
+                        "\\def" ,thenonum "{\\unskip}\n"
+                        ,@before
+                        (newtheorem ,prim* (!option ,nonum) (!translate ,name))
+                        ,@after "\n")))))
 
 (define-macro (latex-texmacs-theorem prim name)
   `(latex-texmacs-thmenv ,prim ,name () ()))
