@@ -18,6 +18,20 @@
 	(dynamic session-drd)
 	(dynamic fold-edit)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Where to find plug-in binaries
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-define (set-manual-path p)
+  (:argument p "Path to plug-in binaries")
+  (:proposals p (if (cpp-has-preference? "manual path")
+                    (list (get-preference "manual path"))
+                    (list)))
+  (if (== p "")
+      (reset-preference "manual path")
+      (set-preference "manual path" p))
+  (restart-message))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Style package rules for sessions
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -42,8 +56,10 @@
 	 (ses (get-env "prog-session")))
     (cons lan ses)))
 
-(tm-define (session-math-input?)
-  (ahash-ref session-math-input (session-key)))
+(tm-define (session-math-input? . opts)
+  (with key (if (< (length opts) 2) (session-key)
+                (cons (car opts) (cadr opts)))
+    (ahash-ref session-math-input key)))
 
 (tm-define (toggle-session-math-input)
   (:synopsis "Toggle mathematical input in sessions.")
@@ -91,6 +107,16 @@
   (:check-mark "v" session-scheme-trees?)
   (set! session-scheme-trees (not session-scheme-trees)))
 
+(define session-scheme-strees #f)
+
+(tm-define (session-scheme-strees?)
+  session-scheme-strees)
+
+(tm-define (toggle-session-scheme-strees)
+  (:synopsis "Toggle pretty scheme tree output in scheme sessions.")
+  (:check-mark "v" session-scheme-strees?)
+  (set! session-scheme-strees (not session-scheme-strees)))
+
 (define session-scheme-math #f)
 
 (tm-define (session-scheme-math?)
@@ -127,13 +153,18 @@
 (define (error-tree? t)
   (and (tree? t) (tree-is? t 'errput)))
 
-(tm-define (scheme-eval t)
+(tm-define (scheme-eval t mode)
   (let* ((s (texmacs->code t "iso-8859-1"))
 	 (r (eval-string-with-catch s)))
     (cond ((and (tree? r) (error-tree? r) (session-scheme-trees?))
            (tree-copy r))
           ((and (tree? r) (session-scheme-trees?))
            (tree 'text (tree-copy r)))
+          ((and (tm? r) (== mode :silent)
+                (or (session-scheme-trees?) (session-scheme-strees?)))
+           (tree-copy (tm->tree r)))
+          ((and (tm? r) (session-scheme-strees?))
+           (tree 'text (tree-copy (tm->tree r))))
           ((session-scheme-math?)
            (with m (cas->stree r)
                  (if (tm? m) (tree 'math (tm->tree m)) (var-object->string r))))
@@ -172,7 +203,7 @@
 	      (not (session-coherent? out next)))
 	  (plugin-next lan ses)
 	  (begin
-	    (plugin-write lan ses in)
+	    (plugin-write lan ses in :session)
 	    (tree-set out :up 0 (plugin-prompt lan ses)))))))
 
 (define (session-next lan ses)
@@ -446,7 +477,7 @@
 
 (tm-define (make-session lan ses)
   (let* ((ban `(output (document "")))
-	 (l (if (session-math-input?) 'input-math 'input))
+	 (l (if (session-math-input? lan ses) 'input-math 'input))
 	 (p (plugin-prompt lan ses))
 	 (in `(,l (document ,p) (document "")))
 	 (s `(session ,lan ,ses (document ,ban ,in))))
@@ -755,3 +786,74 @@
 	(tree-insert (tree-ref v (+ j 1)) 0 `(,lan ,ses))
 	(tree-insert v (+ j 1) '((document "")))
 	(tree-go-to v (+ j 1) :end)))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Copy and paste
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (session-selection-one? t)
+  (and (tree-in? t (cons* 'output 'textput
+                          'folded-subsession 'unfolded-subsession
+                          field-tags))
+       (tree-up t)
+       (session-document-context? (tree-up t))))
+
+(define (session-selection?)
+  (with l (selection-trees)
+    (and (nnull? l) (forall? session-selection-one? l))))
+
+(tm-define (clipboard-cut which)
+  (:require (session-selection?))
+  (let* ((l (selection-trees))
+         (doc (tree-up (car l)))
+         (ses (tree-up doc))
+         (i (tree-index (car l)))
+         (j (tree-index (cAr l)))
+         (k (- (+ j 1) i))
+         (n (tree-arity doc)))
+    (clipboard-copy which)
+    (if (= k n)
+        (tree-cut ses)
+        (let* ((sel `(session ,@(cDr (tm-children ses)) (document ,@l))))
+          (clipboard-set which sel)
+          (tree-remove doc i k)
+          (with next (tree-ref doc (min i (- n (+ k 1))))
+            (cond ((field-context? next)
+                   (tree-go-to next 1 :start))
+                  ((tree-in? next '(output textput))
+                   (tree-go-to next 0 :start))
+                  ((tree-in? next '(folded-subsession unfolded-subsession))
+                   (tree-go-to next 0 :start))
+                  (else (tree-go-to next :start))))))))
+
+(tm-define (clipboard-copy which)
+  (:require (session-selection?))
+  (let* ((l (selection-trees))
+         (doc (tree-up (car l)))
+         (ses (tree-up doc))
+         (sel `(session ,@(cDr (tm-children ses)) (document ,@l))))
+    (clipboard-set which sel)))
+
+(tm-define (inside-subsession-context? t)
+  (and (tree-in? t '(folded-subsession unfolded-subsession))
+       (== (tree-arity t) 2)
+       (cursor-inside? (tree-ref t 1))))
+
+(tm-define (clipboard-paste which)
+  (:require (and (inside? 'session)
+                 (tm-ref (clipboard-get which) 1)
+                 (tree-is? (tm-ref (clipboard-get which) 1) 'session)))
+  (let* ((ses (tree-innermost 'session))
+         (sub (tree-innermost inside-subsession-context?))
+         (ins (tree-ref (clipboard-get which) 1)))
+    (when (and (== (tree-arity ses) 3)
+               (== (tree-arity ins) 3)
+               (tm-equal? (tm-ref ses 0) (tm-ref ins 0)))
+      (let* ((doc (if sub (tree-ref sub 1) (tree-ref ses 2)))
+             (ext (tree-ref ins 2))
+             (i (tree-down-index doc)))
+        (if (== (cursor-path) (tree->path doc i :end))
+            (begin
+              (tree-insert doc (+ i 1) (tree-children ext))
+              (tree-go-to doc (+ i (tree-arity ext)) :end))
+            (tree-insert doc i (tree-children ext)))))))
