@@ -42,7 +42,7 @@
   (with psize (getenv "PAPERSIZE")
     (if (and psize (!= psize "")) psize
         (with papersizefile (or (getenv "PAPERCONF") "/etc/papersize")
-          (and (access? papersizefile R_OK)
+          (and (url-test? papersizefile "r")
                (with pps-port (open-input-file papersizefile)
                  (with size (read-line pps-port)
                    (close-input-port pps-port)
@@ -118,17 +118,21 @@
   (:default  name (propose-postscript-name)))
 
 (tm-property (print-pages first last)
-  (:argument first "First page")
-  (:argument last "Last page"))
+  (:argument  first "First page")
+  (:proposals first (list "1" ""))
+  (:argument  last "Last page")
+  (:proposals last  (list (number->string (get-page-count)) "")))
 
 (tm-property (print-pages-to-file name first last)
-  (:argument name print-file "File name")
-  (:default  name (propose-postscript-name))
-  (:argument first "First page")
-  (:argument last "Last page"))
+  (:argument  name print-file "File name")
+  (:default   name (propose-postscript-name))
+  (:argument  first "First page")
+  (:proposals first (list "1" ""))
+  (:argument  last "Last page")
+  (:proposals last  (list (number->string (get-page-count)) "")))
 
 (tm-define (preview-file u)
-  (with s (url->system u)
+  (with s (url-sys-concretize u)
     (cond ((!= preview-command "default")
            (shell (string-append preview-command " " s " &")))
           ((or (os-mingw?) (os-win32?))
@@ -159,7 +163,9 @@
     (preview-file file)))
 
 (tm-define (choose-file-and-print-page-selection start end)
-  (:argument start "First page")
-  (:argument end "Last page")
+  (:argument  start "First page")
+  (:proposals start (list "1" ""))
+  (:argument  end "Last page")
+  (:proposals end (list (number->string (get-page-count)) ""))
   (choose-file (lambda (name) (print-pages-to-file name start end))
 	       "Print page selection to file" "postscript"))
